@@ -21,7 +21,7 @@ def load(parser, args):
         parser.print_help()
         exit("ERROR: load needs both a VCF file and a database file\n")
 
-    annos = annotations.get_anno_files()
+    annos = annotations.get_anno_files( args )
     # force skipping CADD and GERP if the data files have not been installed
     if args.skip_cadd is False:
         if 'cadd_score' not in annos:
@@ -41,7 +41,7 @@ def load(parser, args):
         else:
             sys.stderr.write("GERP per bp is being loaded (to skip use:--skip-gerp-bp).\n")
     # collect of the the add'l annotation files
-    annotations.load_annos()
+    annotations.load_annos( args )
 
     if args.scheduler:
         load_ipython(args)
