@@ -6,7 +6,7 @@ gemini load -v test.cadd.vcf --skip-gerp-bp test.cadd.db > /dev/null 2>&1
 path=`gemini_python ../gemini/anno_info.py`
 file="whole_genome_SNVs.tsv.compressed.gz"
 
-if [[ -n $(find $path -maxdepth 1 -name "$file") ]]; then
+if [ -f $path/$file ]; then
 
 echo "    cadd.t01...\c"
 echo "chrom	start	end	ref	alt	cadd_raw	cadd_scaled
@@ -60,4 +60,4 @@ gemini query -q "select chrom, start, end, ref, alt, cadd_raw, cadd_scaled from
        > obs
 check obs exp
 rm obs exp
-#####################################################################
\ No newline at end of file
+#####################################################################
